@@ -33,6 +33,7 @@ __all__ = [
     "MIN_SUPPORTED_WIRE_VERSION",
     "CursorType",
     "MongoClient",
+    "AsyncMongoClient",
     "DeleteMany",
     "DeleteOne",
     "IndexModel",
@@ -87,10 +88,9 @@ TEXT = "text"
 
 from pymongo import _csot
 from pymongo._version import __version__, get_version_string, version_tuple
-from pymongo.collection import ReturnDocument
+from pymongo.asynchronous.mongo_client import AsyncMongoClient
 from pymongo.common import MAX_SUPPORTED_WIRE_VERSION, MIN_SUPPORTED_WIRE_VERSION
 from pymongo.cursor import CursorType
-from pymongo.mongo_client import MongoClient
 from pymongo.operations import (
     DeleteMany,
     DeleteOne,
@@ -101,6 +101,8 @@ from pymongo.operations import (
     UpdateOne,
 )
 from pymongo.read_preferences import ReadPreference
+from pymongo.synchronous.collection import ReturnDocument
+from pymongo.synchronous.mongo_client import MongoClient
 from pymongo.write_concern import WriteConcern
 
 version = __version__
