@@ -12,7 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Support for automatic client-side field level encryption."""
+"""Support for automatic client-side field level encryption.
+
+.. seealso:: This module is compatible with both the synchronous and asynchronous PyMongo APIs.
+"""
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Mapping, Optional
@@ -20,6 +23,9 @@ from typing import TYPE_CHECKING, Any, Mapping, Optional
 try:
     import pymongocrypt  # type:ignore[import] # noqa: F401
 
+    # Check for pymongocrypt>=1.10.
+    from pymongocrypt import synchronous as _  # noqa: F401
+
     _HAVE_PYMONGOCRYPT = True
 except ImportError:
     _HAVE_PYMONGOCRYPT = False
@@ -29,8 +35,7 @@ from pymongo.errors import ConfigurationError
 from pymongo.uri_parser import _parse_kms_tls_options
 
 if TYPE_CHECKING:
-    from pymongo.mongo_client import MongoClient
-    from pymongo.typings import _DocumentTypeArg
+    from pymongo.typings import _AgnosticMongoClient, _DocumentTypeArg
 
 
 class AutoEncryptionOpts:
@@ -40,7 +45,7 @@ class AutoEncryptionOpts:
         self,
         kms_providers: Mapping[str, Any],
         key_vault_namespace: str,
-        key_vault_client: Optional[MongoClient[_DocumentTypeArg]] = None,
+        key_vault_client: Optional[_AgnosticMongoClient[_DocumentTypeArg]] = None,
         schema_map: Optional[Mapping[str, Any]] = None,
         bypass_auto_encryption: bool = False,
         mongocryptd_uri: str = "mongodb://localhost:27020",
@@ -65,7 +70,7 @@ class AutoEncryptionOpts:
         users. To configure automatic *decryption* without automatic
         *encryption* set ``bypass_auto_encryption=True``. Explicit
         encryption and explicit decryption is also supported for all users
-        with the :class:`~pymongo.encryption.ClientEncryption` class.
+        with the :class:`~pymongo.asynchronous.encryption.AsyncClientEncryption` and :class:`~pymongo.encryption.ClientEncryption` classes.
 
         See :ref:`automatic-client-side-encryption` for an example.
 
@@ -112,7 +117,7 @@ class AutoEncryptionOpts:
             provider.
         :param key_vault_client: By default, the key vault collection
             is assumed to reside in the same MongoDB cluster as the encrypted
-            MongoClient. Use this option to route data key queries to a
+            AsyncMongoClient/MongoClient. Use this option to route data key queries to a
             separate MongoDB cluster.
         :param schema_map: Map of collection namespace ("db.coll") to
             JSON Schema.  By default, a collection's JSONSchema is periodically
@@ -136,7 +141,7 @@ class AutoEncryptionOpts:
             to the *local* mongocryptd process. Defaults to
             ``'mongodb://localhost:27020'``.
         :param mongocryptd_bypass_spawn: If ``True``, the encrypted
-            MongoClient will not attempt to spawn the mongocryptd process.
+            AsyncMongoClient/MongoClient will not attempt to spawn the mongocryptd process.
             Defaults to ``False``.
         :param mongocryptd_spawn_path: Used for spawning the
             mongocryptd process. Defaults to ``'mongocryptd'`` and spawns
@@ -149,7 +154,7 @@ class AutoEncryptionOpts:
         :param kms_tls_options:  A map of KMS provider names to TLS
             options to use when creating secure connections to KMS providers.
             Accepts the same TLS options as
-            :class:`pymongo.mongo_client.MongoClient`. For example, to
+            :class:`pymongo.mongo_client.AsyncMongoClient` and :class:`pymongo.mongo_client.MongoClient`. For example, to
             override the system default CA file::
 
               kms_tls_options={'kmip': {'tlsCAFile': certifi.where()}}
@@ -229,20 +234,20 @@ class AutoEncryptionOpts:
 
 
 class RangeOpts:
-    """Options to configure encrypted queries using the rangePreview algorithm."""
+    """Options to configure encrypted queries using the range algorithm."""
 
     def __init__(
         self,
-        sparsity: int,
+        sparsity: Optional[int] = None,
+        trim_factor: Optional[int] = None,
         min: Optional[Any] = None,
         max: Optional[Any] = None,
         precision: Optional[int] = None,
     ) -> None:
-        """Options to configure encrypted queries using the rangePreview algorithm.
-
-        .. note:: This feature is experimental only, and not intended for public use.
+        """Options to configure encrypted queries using the range algorithm.
 
         :param sparsity: An integer.
+        :param trim_factor: An integer.
         :param min: A BSON scalar value corresponding to the type being queried.
         :param max: A BSON scalar value corresponding to the type being queried.
         :param precision: An integer, may only be set for double or decimal128 types.
@@ -252,13 +257,15 @@ class RangeOpts:
         self.min = min
         self.max = max
         self.sparsity = sparsity
+        self.trim_factor = trim_factor
         self.precision = precision
 
     @property
     def document(self) -> dict[str, Any]:
         doc = {}
         for k, v in [
-            ("sparsity", int64.Int64(self.sparsity)),
+            ("sparsity", int64.Int64(self.sparsity) if self.sparsity else None),
+            ("trimFactor", self.trim_factor),
             ("precision", self.precision),
             ("min", self.min),
             ("max", self.max),
